==> spip_2.0.8.orig.tar.gz: spip-2.0.8.orig/ecrire/lang/public_oc_lms.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Acuelh dau sit',
'articles' => 'Articles',
'articles_auteur' => 'Articles de quel autor',
'articles_populaires' => 'Los articles mai populars',
'articles_rubrique' => 'Articles de quela rubrica',
'aucun_article' => 'I a brisa d\'article a quela adre&ccedil;a ',
'aucun_auteur' => 'I a brisa d\'autor a quela adre&ccedil;a ',
'aucun_site' => 'I a brisa de sit a quela adre&ccedil;a ',
'aucune_breve' => 'I a brisa de breva a quela adre&ccedil;a ',
'aucune_rubrique' => 'I a brisa de rubrica a quela adre&ccedil;a ',
'autres_breves' => 'Autras brevas',
'autres_groupes_mots_clefs' => 'Autres grops de mots clau',
'autres_sites' => 'Autres sits',

// B
'bonjour' => 'Bonjorn',
'breves' => 'Brevas',

// C
'commenter_site' => 'Comentar queu sit',

// D
'date' => 'Data',
'dernier_ajout' => 'Darrier apondon',
'dernieres_breves' => 'Darrieras brevas',
'derniers_articles' => 'Darriers articles',
'derniers_commentaires' => 'Darriers comentaris',
'derniers_messages_forum' => 'Darriers messatges publicats dins los forums',

// E
'edition_mode_texte' => 'Edicion en m&ograve;de text de',
'en_reponse' => 'En responsa a:',
'en_resume' => 'En resumit',
'envoyer_message' => 'Mandar un messatge',
'espace_prive' => 'Espaci privat',

// F
'forum' => 'Forum',

// H
'hierarchie_site' => 'Ierarquia dau sit',

// J
'jours' => 'jorns',

// M
'meme_auteur' => 'Dau mesme autor',
'meme_rubrique' => 'Dins la mesma rubrica',
'memes_auteurs' => 'Daus mesmes autors',
'message' => 'Messatge',
'messages_forum' => 'Messatges de forum',
'messages_recents' => 'Los messatges de forums mai recents',
'mots_clefs' => 'Mots clau',
'mots_clefs_meme_groupe' => 'Mots clau dins lo mesme grop',

// N
'navigation' => 'Navigacion',
'nom' => 'Nom',
'nouveautes' => 'Las novetats',
'nouveautes_web' => 'Novetats subre lo web',
'nouveaux_articles' => 'Articles nu&ograve;us',
'nouvelles_breves' => 'Brevas nu&ograve;vas',

// P
'page_precedente' => 'pagina precedenta',
'page_suivante' => 'pagina seguenta',
'par_auteur' => 'per&nbsp;',
'participer_site' => 'Podetz participar a la vida de queu sit e prepausar los articles v&ograve;stres en vos inscriure &ccedil;ai jos. Recebretz c&ograve;p sec un e-mail que vos indicar&aacute; v&ograve;stres c&ograve;des per accedir a l\'espaci privat dau sit.',
'plan_site' => 'Plan dau sit',
'popularite' => 'Popularitat',
'poster_message' => 'Postar un messatge',
'proposer_site' => 'Podetz prepausar un sit d\'apondre a questa rubrica:',

// R
'repondre_article' => 'Respondre a quel article',
'repondre_breve' => 'Respondre a quela breva',
'repondre_message' => 'Respondre a queu messatge',
'resultats_recherche' => 'Resultats de la recercha',
'retour_debut_forums' => 'Retorn au comen&ccedil;ament daus forums',
'rubrique' => 'Rubrica',
'rubriques' => 'Rubricas',

// S
'signatures_petition' => 'Signaturas',
'site_realise_avec_spip' => 'Sit realizat emb SPIP',
'sites_web' => 'Sits web',
'sous_rubriques' => 'Sosrubricas',
'suite' => 'seguda',
'sur_web' => 'Subre lo web',
'syndiquer_rubrique' => 'Sindicar quela rubrica',
'syndiquer_site' => 'Sindicar tot lo sit',

// T
'texte_lettre_information' => 'Vaic&iacute; la letra d\'informacion dau sit',
'texte_lettre_information_2' => 'Quela letra recensa los articles e brevas publicats dempuei',

// V
'ver_imprimer' => 'Version d\'estampar',
'voir_en_ligne' => 'Vesetz en linha'
);

?>

==> spip_2.1.1.orig.tar.gz: spip-2.1.1/ecrire/lang/public_oc_lms.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Acuelh dau sit',
'article' => 'Article', # NEW
'articles' => 'Articles',
'articles_auteur' => 'Articles de quel autor',
'articles_populaires' => 'Los articles mai populars',
'articles_rubrique' => 'Articles de quela rubrica',
'aucun_article' => 'I a brisa d\'article a quela adre&ccedil;a ',
'aucun_auteur' => 'I a brisa d\'autor a quela adre&ccedil;a ',
'aucun_site' => 'I a brisa de sit a quela adre&ccedil;a ',
'aucune_breve' => 'I a brisa de breva a quela adre&ccedil;a ',
'aucune_rubrique' => 'I a brisa de rubrica a quela adre&ccedil;a ',
'auteur' => 'Auteur', # NEW
'autres' => 'Autres', # NEW
'autres_breves' => 'Autras brevas',
'autres_groupes_mots_clefs' => 'Autres grops de mots clau',
'autres_sites' => 'Autres sits',

// B
'bonjour' => 'Bonjorn',
'breve' => 'Br&egrave;ve', # NEW
'breves' => 'Brevas',

// C
'commenter_site' => 'Comentar queu sit',
'copie_document_impossible' => 'Impossible de copier le document', # NEW

// D
'date' => 'Data',
'dernier_ajout' => 'Darrier apondon',
'dernieres_breves' => 'Darrieras brevas',
'derniers_articles' => 'Darriers articles',
'derniers_commentaires' => 'Darriers comentaris',
'derniers_messages_forum' => 'Darriers messatges publicats dins los forums',
'documents_interdits_forum' => 'Documents interdits dans le forum', # NEW

// E
'edition_mode_texte' => 'Edicion en m&ograve;de text de',
'en_reponse' => 'En responsa a:',
'en_resume' => 'En resumit',
'envoyer_message' => 'Mandar un messatge',
'espace_prive' => 'Espaci privat',

// F
'formats_acceptes' => 'Formats accept&#233;s : @formats@.', # NEW
'forum' => 'Forum',

// H
'hierarchie_site' => 'Ierarquia dau sit',

// J
'jours' => 'jorns',

// L
'lien_connecter' => 'Se connecter', # NEW

// M
'meme_auteur' => 'Dau mesme autor',
'meme_rubrique' => 'Dins la mesma rubrica',
'memes_auteurs' => 'Daus mesmes autors',
'message' => 'Messatge',
'messages_forum' => 'Messatges de forum',
'messages_recents' => 'Los messatges de forums mai recents',
'mots_clef' => 'Mot-cl&eacute;', # NEW
'mots_clefs' => 'Mots clau',
'mots_clefs_meme_groupe' => 'Mots clau dins lo mesme grop',

// N
'navigation' => 'Navigacion',
'nom' => 'Nom',
'nouveautes' => 'Las novetats',
'nouveautes_web' => 'Novetats subre lo web',
'nouveaux_articles' => 'Articles nu&ograve;us',
'nouvelles_breves' => 'Brevas nu&ograve;vas',

// P
'page_precedente' => 'pagina precedenta',
'page_suivante' => 'pagina seguenta',
'par_auteur' => 'per&nbsp;',
'participer_site' => 'Podetz participar a la vida de queu sit e prepausar los articles v&ograve;stres en vos inscriure &ccedil;ai jos. Recebretz c&ograve;p sec un e-mail que vos indicar&aacute; v&ograve;stres c&ograve;des per accedir a l\'espaci privat dau sit.',
'plan_site' => 'Plan dau sit',
'popularite' => 'Popularitat',
'poster_message' => 'Postar un messatge',
'proposer_site' => 'Podetz prepausar un sit d\'apondre a questa rubrica:',

// R
'repondre_article' => 'Respondre a quel article',
'repondre_breve' => 'Respondre a quela breva',
'repondre_message' => 'Respondre a queu messatge',
'resultats_recherche' => 'Resultats de la recercha',
'retour_debut_forums' => 'Retorn au comen&ccedil;ament daus forums',
'rubrique' => 'Rubrica',
'rubriques' => 'Rubricas',

// S
'signatures_petition' => 'Signaturas',
'site_realise_avec_spip' => 'Sit realizat emb SPIP',
'sites_web' => 'Sits web',
'sous_rubriques' => 'Sosrubricas',
'spam' => 'Spam', # NEW
'suite' => 'seguda',
'sur_web' => 'Subre lo web',
'syndiquer_rubrique' => 'Sindicar quela rubrica',
'syndiquer_site' => 'Sindicar tot lo sit',

// T
'texte_lettre_information' => 'Vaic&iacute; la letra d\'informacion dau sit',
'texte_lettre_information_2' => 'Quela letra recensa los articles e brevas publicats dempuei',

// V
'ver_imprimer' => 'Version d\'estampar',
'voir_en_ligne' => 'Vesetz en linha',
'voir_squelette' => 'voir le squelette de cette page', # NE
);

?>
